@@ -165,7 +165,7 @@ class Manager(object):
             self.build_DescuentosRecargos(root, type)
         self.build_Referencias(root)
         self.build_Compl_Fiscal_Data(root)
-        xml_msg = '<CFE version="1.0" xmlns="http://cfe.dgi.gub.uy">{}</CFE>'.format(tostring(root, 'unicode'))
+        xml_msg = '<CFE version="1.0" xmlns="http://cfe.dgi.gub.uy">{}</CFE>'.format(tostring(root).decode())
         return xml_msg
 
     def build_IdDoc(self, Encabezado):
@@ -489,7 +489,9 @@ class Manager(object):
             for detail in retention.retention_detail:
                 RetencPercep = SubElement(Item[0], "RetencPercep")
                 SubElement(RetencPercep, "CodRet").text = str(retention.retention_code)
-                
+                if hasattr(retention, 'percentage_retention'):
+                    SubElement(RetencPercep, "Tasa").text = self._format_amount(retention.percentage_retention)
+
                 # Se decidio no enviar la tasa dado que puede haber diferencias y el % es legal
                 # en el caso de identificar que comience a ser necesario simplemente se debera
                 # descomentar la siguiente linea.
