@@ -711,26 +711,31 @@ class TestUruware(unittest.TestCase):
 
         retention_detail1 = mock.Mock()
         retention_detail1.amount = 19800
+        retention_detail1.percentage_retention = 100
         retention_detail1.taxable_base = 90000
         retention_detail1.get_tax.return_value = 22
 
         retention_detail2 = mock.Mock()
         retention_detail2.amount = 2200
+        retention_detail2.percentage_retention = 100
         retention_detail2.taxable_base = 10000
         retention_detail2.get_tax.return_value = 22
 
         retention1 = mock.Mock()
         retention1.retention_code = 2183114
+        retention1.percentage_retention = 100
         retention1.retention_detail = [retention_detail1, retention_detail2]
         retention1.get_amount.return_value = 22000
         retention1.get_taxable_base.return_value = 100000
 
         retention_detail3 = mock.Mock()
         retention_detail3.amount = 10000
+        retention_detail3.percentage_retention = 100
         retention_detail3.taxable_base = 10000
         retention_detail3.get_tax.return_value = 22
 
         retention2 = mock.Mock()
+        retention2.percentage_retention = 100
         retention2.retention_code = 2183121
         retention2.retention_detail = [retention_detail3]
         retention2.get_amount.return_value = 10000
@@ -778,15 +783,18 @@ class TestUruware(unittest.TestCase):
 
         retention_detail1 = mock.Mock()
         retention_detail1.amount = 19800
+        retention_detail1.percentage_retention = 100
         retention_detail1.taxable_base = 90000
         retention_detail1.get_tax.return_value = 22
 
         retention_detail2 = mock.Mock()
         retention_detail2.amount = 2200
+        retention_detail2.percentage_retention = 100
         retention_detail2.taxable_base = 10000
         retention_detail2.get_tax.return_value = 22
 
         retention1 = mock.Mock()
+        retention1.percentage_retention = 100
         retention1.retention_code = 2183114
         retention1.retention_detail = [retention_detail1, retention_detail2]
         retention1.get_amount.return_value = 22000
@@ -799,6 +807,7 @@ class TestUruware(unittest.TestCase):
 
         retention2 = mock.Mock()
         retention2.retention_code = 2183121
+        retention2.percentage_retention = 100
         retention2.retention_detail = [retention_detail3]
         retention2.get_amount.return_value = 10000
         retention2.get_taxable_base.return_value = 10000
@@ -827,11 +836,13 @@ class TestUruware(unittest.TestCase):
 
         retention_detail1 = mock.Mock()
         retention_detail1.amount = 2200
+        retention_detail1.percentage_retention = 100
         retention_detail1.taxable_base = 10000
         retention_detail1.get_tax.return_value = 22
 
         retention1 = mock.Mock()
         retention1.retention_code = 2183114
+        retention1.percentage_retention = 100
         retention1.retention_detail = [retention_detail1]
         retention1.get_amount.return_value = 2200
         retention1.get_taxable_base.return_value = 10000
@@ -872,11 +883,13 @@ class TestUruware(unittest.TestCase):
 
         retention_detail1 = mock.Mock()
         retention_detail1.amount = 2200
+        retention_detail1.percentage_retention = 100
         retention_detail1.taxable_base = 10000
         retention_detail1.get_tax.return_value = 22
 
         retention1 = mock.Mock()
         retention1.retention_code = 2183114
+        retention1.percentage_retention = 100
         retention1.retention_detail = [retention_detail1]
         retention1.get_amount.return_value = 2200
         retention1.get_taxable_base.return_value = 10000
@@ -1292,27 +1305,32 @@ class TestUruware(unittest.TestCase):
 
         retention_detail1 = mock.Mock()
         retention_detail1.amount = 19800
+        retention_detail1.percentage_retention = 10
         retention_detail1.taxable_base = 90000
         retention_detail1.get_tax.return_value = 22
 
         retention_detail2 = mock.Mock()
         retention_detail2.amount = 2200
+        retention_detail2.percentage_retention = 10
         retention_detail2.taxable_base = 10000
         retention_detail2.get_tax.return_value = 22
 
         retention1 = mock.Mock()
         retention1.retention_code = 2183114
+        retention1.percentage_retention = 10
         retention1.retention_detail = [retention_detail1, retention_detail2]
         retention1.get_amount.return_value = 22000
         retention1.get_taxable_base.return_value = 100000
 
         retention_detail3 = mock.Mock()
         retention_detail3.amount = 10000
+        retention_detail3.percentage_retention = 10
         retention_detail3.taxable_base = 10000
         retention_detail3.get_tax.return_value = 22
 
         retention2 = mock.Mock()
         retention2.retention_code = 2183121
+        retention2.percentage_retention = 10
         retention2.retention_detail = [retention_detail3]
         retention2.get_amount.return_value = 10000
         retention2.get_taxable_base.return_value = 10000
@@ -1345,11 +1363,13 @@ class TestUruware(unittest.TestCase):
 
         retention_detail1 = mock.Mock()
         retention_detail1.amount = 2200
+        retention_detail1.percentage_retention = 10
         retention_detail1.taxable_base = 10000
         retention_detail1.get_tax.return_value = 22
 
         retention1 = mock.Mock()
         retention1.retention_code = 2183114
+        retention1.percentage_retention = 10
         retention1.retention_detail = [retention_detail1]
         retention1.get_amount.return_value = 2200
         retention1.get_taxable_base.return_value = 10000
